@@ -34,8 +34,6 @@ DEFAULT_ORACLE_CLIENT_LIB_DIR = ''
 DEFAULT_ORACLE_CLIENT_CONFIG_DIR = ''
 
 # DEVELOPMENT OPTIONS
-DEFAULT_PUSH_DOWN_SQL_DISTINCTS = 'no'
-DEFAULT_PUSH_DOWN_SQL_JOINS = 'no'
 DEFAULT_READ_PARSED_MAPPINGS_PATH = ''
 DEFAULT_WRITE_PARSED_MAPPINGS_PATH = ''
 
@@ -53,23 +51,28 @@ NO_PARTITIONING = ['NO', 'FALSE', 'OFF', '0']
 #########################   DATA SOURCE TYPES   ##############################
 ##############################################################################
 
-RDB_SOURCE_TYPE = 'RDB'
-CSV_SOURCE_TYPE = 'CSV'
-TSV_SOURCE_TYPE = 'TSV'
-EXCEL_SOURCE_TYPE = 'EXCEL'
-PARQUET_SOURCE_TYPE = 'PARQUET'
-FEATHER_SOURCE_TYPE = 'FEATHER'
-ORC_SOURCE_TYPE = 'ORC'
-STATA_SOURCE_TYPE = 'STATA'
-SAS_SOURCE_TYPE = 'SAS'
-SPSS_SOURCE_TYPE = 'SPSS'
-JSON_SOURCE_TYPE = 'JSON'
-XML_SOURCE_TYPE = 'XML'
+RDB = 'RDB'
+CSV = 'CSV'
+TSV = 'TSV'
+EXCEL = 'EXCEL'
+PARQUET = 'PARQUET'
+FEATHER = 'FEATHER'
+ORC = 'ORC'
+STATA = 'STATA'
+SAS = 'SAS'
+SPSS = 'SPSS'
+JSON = 'JSON'
+XML = 'XML'
 
-FILE_SOURCE_TYPES = [CSV_SOURCE_TYPE, TSV_SOURCE_TYPE, EXCEL_SOURCE_TYPE, PARQUET_SOURCE_TYPE, FEATHER_SOURCE_TYPE,
-                     ORC_SOURCE_TYPE, STATA_SOURCE_TYPE, SAS_SOURCE_TYPE, SPSS_SOURCE_TYPE, JSON_SOURCE_TYPE,
-                     XML_SOURCE_TYPE]
-DATA_SOURCE_TYPES = [RDB_SOURCE_TYPE] + FILE_SOURCE_TYPES
+# DBMSs
+MYSQL = 'MYSQL'
+MARIADB = 'MARIADB'
+MSSQL = 'MSSQL'
+ORACLE = 'ORACLE'
+POSTGRESQL = 'POSTGRESQL'
+
+FILE_SOURCE_TYPES = [CSV, TSV, EXCEL, PARQUET, FEATHER, ORC, STATA, SAS, SPSS, JSON, XML]
+DATA_SOURCE_TYPES = [RDB] + FILE_SOURCE_TYPES
 
 
 ##############################################################################
