@@ -5,12 +5,12 @@ __license__ = "Apache-2.0"
 __maintainer__ = "Julián Arenas-Guerrero"
 __email__ = "arenas.guerrero.julian@outlook.com"
 
-import sql_metadata
 import pandas as pd
 import numpy as np
 import multiprocessing as mp
 import rdflib
 import logging
+import sql_metadata
 
 from ..constants import *
 from ..utils import replace_predicates_in_graph, get_repeated_elements_in_list, get_mapping_rule_from_triples_map_id
@@ -78,7 +78,7 @@ def _rdf_class_to_pom(mapping_graph):
 
     query = 'SELECT ?tm ?c WHERE { ' \
             '?tm <' + R2RML_SUBJECT_MAP + '> ?sm . ' \
-                                          '?sm <' + R2RML_CLASS + '> ?c . }'
+            '?sm <' + R2RML_CLASS + '> ?c . }'
     for tm, c in mapping_graph.query(query):
         blanknode = rdflib.BNode()
         mapping_graph.add((tm, rdflib.term.URIRef(R2RML_PREDICATE_OBJECT_MAP), blanknode))
@@ -98,15 +98,15 @@ def _subject_graph_maps_to_pom(mapping_graph):
     # add the graph maps in the subject maps to every predicate object map of the subject maps
     query = 'SELECT ?sm ?gm ?pom WHERE { ' \
             '?tm <' + R2RML_SUBJECT_MAP + '> ?sm . ' \
-                                          '?sm <' + R2RML_GRAPH_MAP + '> ?gm . ' \
-                                                                      '?tm <' + R2RML_PREDICATE_OBJECT_MAP + '> ?pom . }'
+            '?sm <' + R2RML_GRAPH_MAP + '> ?gm . ' \
+            '?tm <' + R2RML_PREDICATE_OBJECT_MAP + '> ?pom . }'
     for sm, gm, pom in mapping_graph.query(query):
         mapping_graph.add((pom, rdflib.term.URIRef(R2RML_GRAPH_MAP), gm))
 
     # remove the graph maps from the subject maps
     query = 'SELECT ?sm ?gm WHERE { ' \
             '?tm <' + R2RML_SUBJECT_MAP + '> ?sm . ' \
-                                          '?sm <' + R2RML_GRAPH_MAP + '> ?gm . }'
+            '?sm <' + R2RML_GRAPH_MAP + '> ?gm . }'
     for sm, gm in mapping_graph.query(query):
         mapping_graph.remove((sm, rdflib.term.URIRef(R2RML_GRAPH_MAP), gm))
 
@@ -120,8 +120,8 @@ def _complete_pom_with_default_graph(mapping_graph):
 
     query = 'SELECT DISTINCT ?tm ?pom WHERE { ' \
             '?tm <' + R2RML_PREDICATE_OBJECT_MAP + '> ?pom . ' \
-                                                   'OPTIONAL { ?pom <' + R2RML_GRAPH_MAP + '> ?gm . } . ' \
-                                                                                           'FILTER ( !bound(?gm) ) }'
+            'OPTIONAL { ?pom <' + R2RML_GRAPH_MAP + '> ?gm . } . ' \
+            'FILTER ( !bound(?gm) ) }'
     for tm, pom in mapping_graph.query(query):
         blanknode = rdflib.BNode()
         mapping_graph.add((pom, rdflib.term.URIRef(R2RML_GRAPH_MAP), blanknode))
@@ -139,27 +139,27 @@ def _complete_termtypes(mapping_graph):
     # add missing blanknode termtypes in the constant-valued object maps
     query = 'SELECT DISTINCT ?term_map ?constant WHERE { ' \
             '?term_map <' + R2RML_CONSTANT + '> ?constant . ' \
-                                             'OPTIONAL { ?term_map <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
-                                                                                          'FILTER ( !bound(?termtype) && isBlank(?constant) ) }'
+            'OPTIONAL { ?term_map <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
+            'FILTER ( !bound(?termtype) && isBlank(?constant) ) }'
     for term_map, _ in mapping_graph.query(query):
         mapping_graph.add((term_map, rdflib.term.URIRef(R2RML_TERM_TYPE), rdflib.term.URIRef(R2RML_BLANK_NODE)))
 
     # add missing literal termtypes in the constant-valued object maps
     query = 'SELECT DISTINCT ?term_map ?constant WHERE { ' \
             '?term_map <' + R2RML_CONSTANT + '> ?constant . ' \
-                                             'OPTIONAL { ?term_map <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
-                                                                                          'FILTER ( !bound(?termtype) && isLiteral(?constant) ) }'
+            'OPTIONAL { ?term_map <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
+            'FILTER ( !bound(?termtype) && isLiteral(?constant) ) }'
     for term_map, _ in mapping_graph.query(query):
         mapping_graph.add((term_map, rdflib.term.URIRef(R2RML_TERM_TYPE), rdflib.term.URIRef(R2RML_LITERAL)))
 
     # add missing literal termtypes in the object maps
     query = 'SELECT DISTINCT ?om ?pom WHERE { ' \
             '?pom <' + R2RML_OBJECT_MAP + '> ?om . ' \
-                                          'OPTIONAL { ?om <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
-                                                                                 'OPTIONAL { ?om <' + RML_REFERENCE + '> ?column . } . ' \
-                                                                                                                      'OPTIONAL { ?om <' + R2RML_LANGUAGE + '> ?language . } . ' \
-                                                                                                                                                            'OPTIONAL { ?om <' + R2RML_DATATYPE + '> ?datatype . } . ' \
-                                                                                                                                                                                                  'FILTER ( !bound(?termtype) && ( bound(?column) || bound(?language) || bound(?datatype) ) ) }'
+            'OPTIONAL { ?om <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
+            'OPTIONAL { ?om <' + RML_REFERENCE + '> ?column . } . ' \
+            'OPTIONAL { ?om <' + R2RML_LANGUAGE + '> ?language . } . ' \
+            'OPTIONAL { ?om <' + R2RML_DATATYPE + '> ?datatype . } . ' \
+            'FILTER ( !bound(?termtype) && ( bound(?column) || bound(?language) || bound(?datatype) ) ) }'
     for om, _ in mapping_graph.query(query):
         mapping_graph.add((om, rdflib.term.URIRef(R2RML_TERM_TYPE), rdflib.term.URIRef(R2RML_LITERAL)))
 
@@ -167,8 +167,8 @@ def _complete_termtypes(mapping_graph):
     for term_map_property in [R2RML_SUBJECT_MAP, R2RML_PREDICATE_MAP, R2RML_OBJECT_MAP, R2RML_GRAPH_MAP]:
         query = 'SELECT DISTINCT ?term_map ?x WHERE { ' \
                 '?x <' + term_map_property + '> ?term_map . ' \
-                                             'OPTIONAL { ?term_map <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
-                                                                                          'FILTER ( !bound(?termtype) ) }'
+                'OPTIONAL { ?term_map <' + R2RML_TERM_TYPE + '> ?termtype . } . ' \
+                'FILTER ( !bound(?termtype) ) }'
         for term_map, _ in mapping_graph.query(query):
             mapping_graph.add((term_map, rdflib.term.URIRef(R2RML_TERM_TYPE), rdflib.term.URIRef(R2RML_IRI)))
 
@@ -432,14 +432,17 @@ class MappingParser:
                     self.mappings_df.at[i, 'join_conditions'] = str(join_conditions)
 
     def _remove_self_joins_from_mappings(self):
+
+        # because RDB has no rml:source, use source_name for rml:source to facilitate self-join elimination
+        self.mappings_df.loc[self.mappings_df['source_type'] == RDB, 'data_source'] = self.mappings_df['source_name']
+
         for i, mapping_rule in self.mappings_df.iterrows():
             if pd.notna(mapping_rule['object_parent_triples_map']):
                 parent_triples_map_rule = get_mapping_rule_from_triples_map_id(self.mappings_df, mapping_rule[
                     'object_parent_triples_map'])
 
                 # str() is to be able to compare np.nan
-                if str(mapping_rule['source_name']) == str(parent_triples_map_rule['source_name']) and \
-                        str(mapping_rule['data_source']) == str(parent_triples_map_rule['data_source']) and \
+                if str(mapping_rule['data_source']) == str(parent_triples_map_rule['data_source']) and \
                         str(mapping_rule['tablename']) == str(parent_triples_map_rule['tablename']) and \
                         str(mapping_rule['iterator']) == str(parent_triples_map_rule['iterator']) and \
                         str(mapping_rule['query']) == str(parent_triples_map_rule['query']):
@@ -480,18 +483,17 @@ class MappingParser:
             # datatype inferring only applies to relational data sources
             if (mapping_rule['source_type'] == RDB) and (
                     # datatype inferring only applies to literals
-                    mapping_rule['object_termtype'] == R2RML_LITERAL) and (
+                    str(mapping_rule['object_termtype']) == R2RML_LITERAL) and (
                     # if the literal has a language tag or an overridden datatype, datatype inference does not apply
                     pd.isna(mapping_rule['object_datatype']) and pd.isna(mapping_rule['object_language'])):
 
                 if pd.notna(mapping_rule['tablename']) and pd.notna(mapping_rule['object_reference']):
-                    inferred_data_type = get_column_datatype(
-                        self.config, mapping_rule['source_name'], mapping_rule['tablename'],
-                        mapping_rule['object_reference']
-                    )
+                    inferred_data_type = get_column_datatype(self.config, mapping_rule['source_name'],
+                                                             mapping_rule['tablename'],
+                                                             mapping_rule['object_reference'])
 
-                    self.mappings_df.at[i, 'object_datatype'] = inferred_data_type
                     if inferred_data_type:
+                        self.mappings_df.at[i, 'object_datatype'] = inferred_data_type
                         logging.debug("`" + inferred_data_type + "` datatype inferred for column `" +
                                       mapping_rule['object_reference'] + "` of table `" +
                                       mapping_rule['tablename'] + "` in data source `" +
@@ -499,19 +501,17 @@ class MappingParser:
 
                 elif pd.notna(mapping_rule['query']):
                     # if mapping rule has a query, get the table names in the query
-                    table_names = sql_metadata.get_query_tables(mapping_rule['query'])
+                    table_names = sql_metadata.Parser(mapping_rule['query']).tables
                     for table_name in table_names:
                         # for each table in the query get the datatype of the object reference in that table if an
                         # exception is thrown, then the reference is not a column in that table, and nothing is done
                         try:
-                            data_type = get_column_datatype(
-                                self.config, mapping_rule['source_name'], table_name,
-                                mapping_rule['object_reference']
-                            )
+                            inferred_data_type = get_column_datatype(self.config, mapping_rule['source_name'],
+                                                                     table_name, mapping_rule['object_reference'])
 
-                            self.mappings_df.at[i, 'object_datatype'] = data_type
-                            if data_type:
-                                logging.debug("`" + data_type + "` datatype inferred for reference `" +
+                            if inferred_data_type:
+                                self.mappings_df.at[i, 'object_datatype'] = inferred_data_type
+                                logging.debug("`" + inferred_data_type + "` datatype inferred for reference `" +
                                               mapping_rule['object_reference'] + "` in query [" +
                                               mapping_rule['query'] + "] in data source `" +
                                               mapping_rule['source_name'] + "`.")
@@ -532,15 +532,14 @@ class MappingParser:
         # not a rr:literal). Use subset operation
         subject_termtypes = set([str(termtype) for termtype in set(self.mappings_df['subject_termtype'])])
         if not (subject_termtypes <= {R2RML_IRI, R2RML_BLANK_NODE}):
-            raise ValueError('Found an invalid subject termtype. Found values ' + str(subject_termtypes) + \
-                             '. Subject maps must be ' + R2RML_IRI + ' or ' + R2RML_BLANK_NODE + \
-                             '.')
+            raise ValueError('Found an invalid subject termtype. Found values ' + str(subject_termtypes) +
+                             '. Subject maps must be ' + R2RML_IRI + ' or ' + R2RML_BLANK_NODE + '.')
 
         object_termtypes = set([str(termtype) for termtype in set(self.mappings_df['object_termtype'])])
         if not (object_termtypes <= {R2RML_IRI, R2RML_BLANK_NODE, R2RML_LITERAL}):
-            raise ValueError('Found an invalid object termtype. Found values ' + str(object_termtypes) + \
-                             '. Object maps must be ' + R2RML_IRI + ', ' + R2RML_BLANK_NODE + \
-                             ' or ' + R2RML_LITERAL + '.')
+            raise ValueError('Found an invalid object termtype. Found values ' + str(object_termtypes) +
+                             '. Object maps must be ' + R2RML_IRI + ', ' + R2RML_BLANK_NODE + ' or ' +
+                             R2RML_LITERAL + '.')
 
         # if there is a datatype or language tag then the object map termtype must be a rr:Literal
         if len(self.mappings_df.loc[(self.mappings_df['object_termtype'] != R2RML_LITERAL) &
