@@ -13,6 +13,7 @@ import logging
 import rdflib
 import time
 import numpy as np
+import pandas as pd
 
 
 def configure_logger(logging_level, logging_file):
@@ -212,10 +213,12 @@ def get_references_in_join_condition(mapping_rule):
     references = list()
     parent_references = list()
 
-    join_conditions = eval(mapping_rule['join_conditions'])
-    for join_condition in join_conditions.values():
-        references.append(join_condition['child_value'])
-        parent_references.append(join_condition['parent_value'])
+    # if join_condition is not null and it is not empty
+    if pd.notna(mapping_rule['join_conditions']) and mapping_rule['join_conditions']:
+        join_conditions = eval(mapping_rule['join_conditions'])
+        for join_condition in join_conditions.values():
+            references.append(join_condition['child_value'])
+            parent_references.append(join_condition['parent_value'])
 
     return references, parent_references
 
